# LOBSTER

The **L**ightweight **O**pen **B**MW **S**oftware **T**raceability
**E**vidence **R**eport allows you to demonstrate software traceability
and requirements coverage, which is essential for meeting standards
such as ISO 26262.

This package contains a tool to interface with the proprietary
requirements management tool
[Codebeamer](https://intland.com/codebeamer).

## Tools

* `lobster-codebeamer`: Extrat requirements from codebeamer.

## Configuration
This tool works with an optional config file.
It allows to configure the following features:

### References
Codebeamer items can reference other items through
[Reference Fields](https://support.ptc.com/help/codebeamer/r2.1/en/index.html#page/codebeamer/user_guide/ug_reference_fields.html).
This piece of information can be extracted by the tool, and serialized into the
LOBSTER output file.
It only needs to know which fields to take into account.
Following the LOBSTER JSON schema, the item references will be added to the
`refs` property of the LOBSTER item.
Accordingly, the configuration parameter to specify the codebeamer field names
is called `refs`, too. 
It can contain a single field name, or a list of field names.
Field IDs cannot be used, only the field names.

Examples:
```json
{
  "refs" : "cb-fieldname"
}
```
or
```json
{
  "refs" : ["cb-fieldname"]
}
```
or
```json
{
  "refs" : ["cb-fieldname1", "cb-fieldname2"]
}
```

### Bearer Authentication Token
It is also possible to define the Bearer authentication token in the
configuration file:
```json
{
  "token" : "your-codebeamer-Bearer-token"
}
```
Note:
- The Bearer authentication token can also be provided as a command line
  argument (use `--cb-token=your-codebeamer-Bearer-token`).
- If the token is provided in the configuration file and as command line
  argument, then the configuration file takes precedence.
- If `--cb-user` or `--cb-pass` is given together with a Bearer token (either
  as a command line argument or through the configuration file), then the
  Bearer authentication method is used, and the username and/or password are
  ignored.
- If neither a token nor a username or password are given, then the tool tries
  to read the username and password from the `.netrc` file in the user's home
  directory.

### Example Configuration
Here is an example configuration file:
```json
{
  "refs" : ["derived from", "satisfied by"],
  "token" : "SomeTokenStringABC123"
}
```

Is it also possible to define the codebeamer token in this file:
```
{
"refs" : "cb-fieldname",
"token" : "your cb-token"
}
```

## Usage

There are two ways you can use this tool:

1. Download all requirements mentioned by another lobster trace (this
  way you do not get a completeness check) (using `--import-tagged`)

2. Download all requirements generated by a saved codebeamer query
  (using `--import-query`)

## Limitations

The key limitation is item text, which is currently not
imported. However, we do plan to also import item text eventually.

## Copyright & License information

The copyright holder of LOBSTER is the Bayerische Motoren Werke
Aktiengesellschaft (BMW AG), and LOBSTER is published under the [GNU
Affero General Public License, Version
3](https://github.com/bmw-software-engineering/lobster/blob/main/LICENSE.md).

This tool has no actual dependency on, or with, Codebeamer. It just
talks the API as described here: https://codebeamer.com/cb/wiki/117612
